module gmii_udp_loopback_test(
    clk,
	rst_n,
	
	gmii_gtxc,
	gmii_txd,
	gmii_txen,
	
	gmii_rxc,
	gmii_rxd,
	gmii_rxdv,

	eth_rst_n
);
    
    input clk;
	input rst_n;
	
	output gmii_gtxc;
	output [7:0]gmii_txd;
	output gmii_txen;
	
	input gmii_rxc;
	input [7:0]gmii_rxd;
	input gmii_rxdv;

	output eth_rst_n;

	assign eth_rst_n = 1;
	wire [7:0]fifo_wrdata;
	wire fifo_wrreq;

	wire clk125M_o;
	wire [15:0]rx_data_length;
	wire one_pkt_done;
	
	//上电后先清零fifo
	reg [23:0]delay_cnt;
	always@(posedge clk or negedge rst_n)
	begin
		if(!rst_n)
			delay_cnt <= 24'd0;
		else if(delay_cnt >= 24'hfffffd)
			delay_cnt <= delay_cnt;
		else
			delay_cnt <= delay_cnt + 1'd1;
	end
	
	wire fifo_aclr;
	assign fifo_aclr = (delay_cnt >= 24'd100)?1'b0:1'b1;	
	
	assign gmii_gtxc = gmii_rxc;
	
	UDP_Send UDP_Send(
		.Clk			(						),
		.GMII_GTXC		(gmii_gtxc				),
		.GMII_TXD		(gmii_txd				),
		.GMII_TXEN		(gmii_txen				),
		.Rst_n			(rst_n					),
		.Go				(one_pkt_done			),
		.Tx_Done		(						),
		.data_length	(rx_data_length			),
		.des_ip			(32'hc0_a8_00_03		),
		.des_mac		(48'hFF_FF_FF_FF_FF_FF	),
		.des_port		(16'd6000				),
		.src_ip			(32'hc0_a8_00_02		),
		.src_mac		(48'h00_0a_35_01_fe_c0	),
		.src_port		(16'd5000				),
		.wrclk			(clk125M_o				),
		.wrdata			(fifo_wrdata			),
		.wrreq			(fifo_wrreq				),
		.aclr			(fifo_aclr				),
		.wrusedw		(						)
	);
	
	udp_gmii_rx udp_gmii_rx(
		.reset_n  		(rst_n                 ),
		
		.gmii_rx_en    	(1'b1                  ),
		
		.local_mac     	(48'h00_0a_35_01_fe_c0 ),
		.local_ip      	(32'hc0_a8_00_02       ),
		.local_port    	(16'd5000              ),
		
		.fifo_full     	(0             		  ),
		.fifo_wr       	(fifo_wrreq            ),
		.fifo_din      	(fifo_wrdata           ),
		.clk125M_o     	(clk125M_o             ),
		
		.exter_mac     	(                      ),
		.exter_ip      	(                      ),
		.exter_port    	(                      ),
		.rx_data_length	(rx_data_length        ),
		
		.one_pkt_done  	(one_pkt_done          ),
		.pkt_error     	(                      ),
		.debug_cal_crc 	(                      ),
		
		.gmii_rx_clk   	(gmii_rxc              ),
		.gmii_rxdv     	(gmii_rxdv             ),
		.gmii_rxd      	(gmii_rxd              )
	);
    
endmodule
